==> apache-camel-3.14.0-src.zip: apache-camel-3.14.0/components/camel-jetty/src/test/java/org/apache/camel/component/jetty/rest/RestApiJettyYamlTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jetty.rest;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertTrue;

@Disabled("Does not run well on CI due test uses JMX mbeans")
public class RestApiJettyYamlTest extends RestApiJettyTest {

    @Override
    @Test
    public void testApi() throws Exception {
        String out = template.requestBody("jetty:http://localhost:{{port}}/api-doc/swagger.yaml", null, String.class);
        assertNotNull(out);
        assertTrue(out.contains("version: \"1.2.3\""));
        assertTrue(out.contains("title: \"The hello rest thing"));
        assertTrue(out.contains("/hello/bye:"));
        assertTrue(out.contains("- \"hello\""));
        assertTrue(out.contains("/hello/bye/{name}:"));
        assertTrue(out.contains("- name: \"name\""));
    }

}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-jetty/src/test/java/org/apache/camel/component/jetty/rest/RestApiJettyYamlTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jetty.rest;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertTrue;

@Disabled("Does not run well on CI due test uses JMX mbeans")
public class RestApiJettyYamlTest extends RestApiJettyTest {

    @Override
    @Test
    public void testApi() {
        String out = template.requestBody("jetty:http://localhost:{{port}}/api-doc/swagger.yaml", null, String.class);
        assertNotNull(out);
        assertTrue(out.contains("version: \"1.2.3\""));
        assertTrue(out.contains("title: \"The hello rest thing"));
        assertTrue(out.contains("/hello/bye:"));
        assertTrue(out.contains("- \"hello\""));
        assertTrue(out.contains("/hello/bye/{name}:"));
        assertTrue(out.contains("- name: \"name\""));
    }

}
